@@ -1,5 +1,5 @@
 # Internal generic GET function for estimating p-value.
-estimate_p_value <- function (x, ...) UseMethod('estimate_p_value')
+#estimate_p_value <- function (x, ...) UseMethod('estimate_p_value')
 
 # FIXME: Do we need to consider NA values at some point in life? Our
 # methods should not produce them but if we export this function, they
@@ -30,7 +30,7 @@ estimate_p_value <- function (x, ...) UseMethod('estimate_p_value')
 # @param ... Additional arguments.
 # @return The p-value estimate. A scalar real value between 0 and 1.
 # @references Hájek & Šidák & Sen. Theory of Rank Tests. 1999. ff. 130.
-estimate_p_value.default <- function(x, sim_vec, ties = 'conservative', ...) {
+estimate_p_value <- function(x, sim_vec, ties = 'conservative', ...) {
     obs <- x
     if (length(obs) != 1L || !is.finite(obs) || !is.numeric(obs)) {
         stop('obs must be a scalar finite real value.')
